==> qupzilla_1.4.1.orig.tar.gz: qupzilla-1.4.1.orig/src/plugins/AccessKeysNavigation/translations/id_ID.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="id_ID" version="2.0">
<context>
    <name>AKN_Settings</name>
    <message>
        <location filename="../akn_settings.ui" line="14"/>
        <source>Access Keys Navigation</source>
        <translation>Navigasi Tombol Akses</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="20"/>
        <source>&lt;h1&gt;Access Keys Navigation&lt;/h1&gt;</source>
        <translation>&lt;h1&gt;Navigasi Tombol Akses&lt;/h1&gt;</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="33"/>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="38"/>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="43"/>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="51"/>
        <source>Double press</source>
        <translation>Tekan dobel</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="58"/>
        <source>Key for showing access keys:</source>
        <translation>Tombol untuk menampilkan tombol akses:</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="103"/>
        <source>License</source>
        <translation>Lisensi</translation>
    </message>
</context>
</TS>

==> qupzilla_1.6.0.orig.tar.gz: qupzilla-1.6.0/src/plugins/AccessKeysNavigation/translations/id_ID.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="id_ID" version="2.0">
<context>
    <name>AKN_Settings</name>
    <message>
        <location filename="../akn_settings.ui" line="14"/>
        <source>Access Keys Navigation</source>
        <translation>Navigasi Tombol Akses</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="20"/>
        <source>&lt;h1&gt;Access Keys Navigation&lt;/h1&gt;</source>
        <translation>&lt;h1&gt;Navigasi Tombol Akses&lt;/h1&gt;</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="33"/>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="38"/>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="43"/>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="51"/>
        <source>Double press</source>
        <translation>Pencet dobel</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="58"/>
        <source>Key for showing access keys:</source>
        <translation>Tombol untuk menampilkan tombol akses:</translation>
    </message>
    <message>
        <location filename="../akn_settings.ui" line="103"/>
        <source>License</source>
        <translation>Lisensi</translation>
    </message>
</context>
</TS>
